==> eam-wshub-proxyclient-12.1-1-sources.jar: net/datastream/schemas/mp_functions/mp7834_001/MP7834_SyncCustomerRental_001.java <==

package net.datastream.schemas.mp_functions.mp7834_001;

import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlAttribute;
import jakarta.xml.bind.annotation.XmlElement;
import jakarta.xml.bind.annotation.XmlRootElement;
import jakarta.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_entities.customerrental_001.CustomerRental;
import net.datastream.schemas.mp_fields.NOUN_Type;
import net.datastream.schemas.mp_fields.VERB_Type;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>{@code
 * <complexType>
 *   <complexContent>
 *     <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       <sequence>
 *         <element ref="{http://schemas.datastream.net/MP_entities/CustomerRental_001}CustomerRental"/>
 *       </sequence>
 *       <attribute name="verb" type="{http://schemas.datastream.net/MP_fields}VERB_Type" fixed="Sync" />
 *       <attribute name="noun" type="{http://schemas.datastream.net/MP_fields}NOUN_Type" fixed="CustomerRental" />
 *       <attribute name="version" type="{http://schemas.datastream.net/MP_fields}VERSION" fixed="001" />
 *       <attribute name="confirm_physicalmeter" type="{http://schemas.datastream.net/MP_fields}CONFIRMATION_Type" default="not_needed" />
 *       <attribute name="confirm_rollovercheck" type="{http://schemas.datastream.net/MP_fields}CONFIRMATION_Type" />
 *       <attribute name="confirm_physicalrollover" type="{http://schemas.datastream.net/MP_fields}CONFIRMATION_Type" default="not_needed" />
 *       <attribute name="confirm_rentalsexist" type="{http://schemas.datastream.net/MP_fields}CONFIRMATION_Type" default="not_needed" />
 *       <attribute name="confirm_invoicesexist" type="{http://schemas.datastream.net/MP_fields}CONFIRMATION_Type" default="not_needed" />
 *     </restriction>
 *   </complexContent>
 * </complexType>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "customerRental"
})
@XmlRootElement(name = "MP7834_SyncCustomerRental_001")
public class MP7834_SyncCustomerRental_001 {

    @XmlElement(name = "CustomerRental", namespace = "http://schemas.datastream.net/MP_entities/CustomerRental_001", required = true)
    protected CustomerRental customerRental;
    @XmlAttribute(name = "verb")
    protected VERB_Type verb;
    @XmlAttribute(name = "noun")
    protected NOUN_Type noun;
    @XmlAttribute(name = "version")
    protected String version;
    @XmlAttribute(name = "confirm_physicalmeter")
    protected String confirm_Physicalmeter;
    @XmlAttribute(name = "confirm_rollovercheck")
    protected String confirm_Rollovercheck;
    @XmlAttribute(name = "confirm_physicalrollover")
    protected String confirm_Physicalrollover;
    @XmlAttribute(name = "confirm_rentalsexist")
    protected String confirm_Rentalsexist;
    @XmlAttribute(name = "confirm_invoicesexist")
    protected String confirm_Invoicesexist;

    /**
     * Gets the value of the customerRental property.
     * 
     * @return
     *     possible object is
     *     {@link CustomerRental }
     *     
     */
    public CustomerRental getCustomerRental() {
        return customerRental;
    }

    /**
     * Sets the value of the customerRental property.
     * 
     * @param value
     *     allowed object is
     *     {@link CustomerRental }
     *     
     */
    public void setCustomerRental(CustomerRental value) {
        this.customerRental = value;
    }

    /**
     * Gets the value of the verb property.
     * 
     * @return
     *     possible object is
     *     {@link VERB_Type }
     *     
     */
    public VERB_Type getVerb() {
        if (verb == null) {
            return VERB_Type.SYNC;
        } else {
            return verb;
        }
    }

    /**
     * Sets the value of the verb property.
     * 
     * @param value
     *     allowed object is
     *     {@link VERB_Type }
     *     
     */
    public void setVerb(VERB_Type value) {
        this.verb = value;
    }

    /**
     * Gets the value of the noun property.
     * 
     * @return
     *     possible object is
     *     {@link NOUN_Type }
     *     
     */
    public NOUN_Type getNoun() {
        if (noun == null) {
            return NOUN_Type.CUSTOMER_RENTAL;
        } else {
            return noun;
        }
    }

    /**
     * Sets the value of the noun property.
     * 
     * @param value
     *     allowed object is
     *     {@link NOUN_Type }
     *     
     */
    public void setNoun(NOUN_Type value) {
        this.noun = value;
    }

    /**
     * Gets the value of the version property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getVersion() {
        if (version == null) {
            return "001";
        } else {
            return version;
        }
    }

    /**
     * Sets the value of the version property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setVersion(String value) {
        this.version = value;
    }

    /**
     * Gets the value of the confirm_Physicalmeter property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getConfirm_Physicalmeter() {
        if (confirm_Physicalmeter == null) {
            return "not_needed";
        } else {
            return confirm_Physicalmeter;
        }
    }

    /**
     * Sets the value of the confirm_Physicalmeter property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setConfirm_Physicalmeter(String value) {
        this.confirm_Physicalmeter = value;
    }

    /**
     * Gets the value of the confirm_Rollovercheck property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getConfirm_Rollovercheck() {
        return confirm_Rollovercheck;
    }

    /**
     * Sets the value of the confirm_Rollovercheck property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setConfirm_Rollovercheck(String value) {
        this.confirm_Rollovercheck = value;
    }

    /**
     * Gets the value of the confirm_Physicalrollover property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getConfirm_Physicalrollover() {
        if (confirm_Physicalrollover == null) {
            return "not_needed";
        } else {
            return confirm_Physicalrollover;
        }
    }

    /**
     * Sets the value of the confirm_Physicalrollover property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setConfirm_Physicalrollover(String value) {
        this.confirm_Physicalrollover = value;
    }

    /**
     * Gets the value of the confirm_Rentalsexist property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getConfirm_Rentalsexist() {
        if (confirm_Rentalsexist == null) {
            return "not_needed";
        } else {
            return confirm_Rentalsexist;
        }
    }

    /**
     * Sets the value of the confirm_Rentalsexist property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setConfirm_Rentalsexist(String value) {
        this.confirm_Rentalsexist = value;
    }

    /**
     * Gets the value of the confirm_Invoicesexist property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getConfirm_Invoicesexist() {
        if (confirm_Invoicesexist == null) {
            return "not_needed";
        } else {
            return confirm_Invoicesexist;
        }
    }

    /**
     * Sets the value of the confirm_Invoicesexist property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setConfirm_Invoicesexist(String value) {
        this.confirm_Invoicesexist = value;
    }

}

==> eam-wshub-proxyclient-12.1-4-sources.jar: net/datastream/schemas/mp_functions/mp7834_001/MP7834_SyncCustomerRental_001.java <==

package net.datastream.schemas.mp_functions.mp7834_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_entities.customerrental_001.CustomerRental;
import net.datastream.schemas.mp_fields.NOUN_Type;
import net.datastream.schemas.mp_fields.VERB_Type;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_entities/CustomerRental_001}CustomerRental"/>
 *       &lt;/sequence>
 *       &lt;attribute name="verb" type="{http://schemas.datastream.net/MP_fields}VERB_Type" fixed="Sync" />
 *       &lt;attribute name="noun" type="{http://schemas.datastream.net/MP_fields}NOUN_Type" fixed="CustomerRental" />
 *       &lt;attribute name="version" type="{http://schemas.datastream.net/MP_fields}VERSION" fixed="001" />
 *       &lt;attribute name="confirm_physicalmeter" type="{http://schemas.datastream.net/MP_fields}CONFIRMATION_Type" default="not_needed" />
 *       &lt;attribute name="confirm_rollovercheck" type="{http://schemas.datastream.net/MP_fields}CONFIRMATION_Type" />
 *       &lt;attribute name="confirm_physicalrollover" type="{http://schemas.datastream.net/MP_fields}CONFIRMATION_Type" default="not_needed" />
 *       &lt;attribute name="confirm_rentalsexist" type="{http://schemas.datastream.net/MP_fields}CONFIRMATION_Type" default="not_needed" />
 *       &lt;attribute name="confirm_invoicesexist" type="{http://schemas.datastream.net/MP_fields}CONFIRMATION_Type" default="not_needed" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "customerRental"
})
@XmlRootElement(name = "MP7834_SyncCustomerRental_001")
public class MP7834_SyncCustomerRental_001 {

    @XmlElement(name = "CustomerRental", namespace = "http://schemas.datastream.net/MP_entities/CustomerRental_001", required = true)
    protected CustomerRental customerRental;
    @XmlAttribute(name = "verb")
    protected VERB_Type verb;
    @XmlAttribute(name = "noun")
    protected NOUN_Type noun;
    @XmlAttribute(name = "version")
    protected String version;
    @XmlAttribute(name = "confirm_physicalmeter")
    protected String confirm_Physicalmeter;
    @XmlAttribute(name = "confirm_rollovercheck")
    protected String confirm_Rollovercheck;
    @XmlAttribute(name = "confirm_physicalrollover")
    protected String confirm_Physicalrollover;
    @XmlAttribute(name = "confirm_rentalsexist")
    protected String confirm_Rentalsexist;
    @XmlAttribute(name = "confirm_invoicesexist")
    protected String confirm_Invoicesexist;

    /**
     * Gets the value of the customerRental property.
     * 
     * @return
     *     possible object is
     *     {@link CustomerRental }
     *     
     */
    public CustomerRental getCustomerRental() {
        return customerRental;
    }

    /**
     * Sets the value of the customerRental property.
     * 
     * @param value
     *     allowed object is
     *     {@link CustomerRental }
     *     
     */
    public void setCustomerRental(CustomerRental value) {
        this.customerRental = value;
    }

    /**
     * Gets the value of the verb property.
     * 
     * @return
     *     possible object is
     *     {@link VERB_Type }
     *     
     */
    public VERB_Type getVerb() {
        if (verb == null) {
            return VERB_Type.SYNC;
        } else {
            return verb;
        }
    }

    /**
     * Sets the value of the verb property.
     * 
     * @param value
     *     allowed object is
     *     {@link VERB_Type }
     *     
     */
    public void setVerb(VERB_Type value) {
        this.verb = value;
    }

    /**
     * Gets the value of the noun property.
     * 
     * @return
     *     possible object is
     *     {@link NOUN_Type }
     *     
     */
    public NOUN_Type getNoun() {
        if (noun == null) {
            return NOUN_Type.CUSTOMER_RENTAL;
        } else {
            return noun;
        }
    }

    /**
     * Sets the value of the noun property.
     * 
     * @param value
     *     allowed object is
     *     {@link NOUN_Type }
     *     
     */
    public void setNoun(NOUN_Type value) {
        this.noun = value;
    }

    /**
     * Gets the value of the version property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getVersion() {
        if (version == null) {
            return "001";
        } else {
            return version;
        }
    }

    /**
     * Sets the value of the version property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setVersion(String value) {
        this.version = value;
    }

    /**
     * Gets the value of the confirm_Physicalmeter property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getConfirm_Physicalmeter() {
        if (confirm_Physicalmeter == null) {
            return "not_needed";
        } else {
            return confirm_Physicalmeter;
        }
    }

    /**
     * Sets the value of the confirm_Physicalmeter property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setConfirm_Physicalmeter(String value) {
        this.confirm_Physicalmeter = value;
    }

    /**
     * Gets the value of the confirm_Rollovercheck property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getConfirm_Rollovercheck() {
        return confirm_Rollovercheck;
    }

    /**
     * Sets the value of the confirm_Rollovercheck property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setConfirm_Rollovercheck(String value) {
        this.confirm_Rollovercheck = value;
    }

    /**
     * Gets the value of the confirm_Physicalrollover property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getConfirm_Physicalrollover() {
        if (confirm_Physicalrollover == null) {
            return "not_needed";
        } else {
            return confirm_Physicalrollover;
        }
    }

    /**
     * Sets the value of the confirm_Physicalrollover property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setConfirm_Physicalrollover(String value) {
        this.confirm_Physicalrollover = value;
    }

    /**
     * Gets the value of the confirm_Rentalsexist property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getConfirm_Rentalsexist() {
        if (confirm_Rentalsexist == null) {
            return "not_needed";
        } else {
            return confirm_Rentalsexist;
        }
    }

    /**
     * Sets the value of the confirm_Rentalsexist property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setConfirm_Rentalsexist(String value) {
        this.confirm_Rentalsexist = value;
    }

    /**
     * Gets the value of the confirm_Invoicesexist property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getConfirm_Invoicesexist() {
        if (confirm_Invoicesexist == null) {
            return "not_needed";
        } else {
            return confirm_Invoicesexist;
        }
    }

    /**
     * Sets the value of the confirm_Invoicesexist property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setConfirm_Invoicesexist(String value) {
        this.confirm_Invoicesexist = value;
    }

}
